module.exports = function(grunt) {

    grunt.initConfig({
        pkg: grunt.file.readJSON('package.json'),
        concat: {
            options: {
                separator: ';'
            },
            dist: {
                src: ['<%= pkg.webrootPath %>com/js/jquery/*.js', '<%= pkg.webrootPath %>com/js/**/*.js', '<%= pkg.webrootPath %>js/*.js'],
                dest: '<%= pkg.webrootPath %>js/all.min.js'
            }
        },
        uglify: {
            options: {
                banner: '/*! <%= pkg.name %> <%= grunt.template.today("yyyy") %> */\n'
            },
            dist: {
                files: {
                    '<%= pkg.webrootPath %>js/interface.min.js': ['<%= concat.dist.dest %>']
                }
            }
        },
        cssmin: {
            combine: {
                files: {
                    '<%= pkg.webrootPath %>css/style.concat.css': ['<%= pkg.webrootPath %>css/*.css', '!*.min.css', '!*.concat.css']
                }
            },
            minify: {
                expand: true,
                cwd: '<%= pkg.webrootPath %>css/',
                src: ['<%= pkg.webrootPath %>style.concat.css'],
                dest: '<%= pkg.webrootPath %>css/',
                ext: '.min.css'
            }
        },
        csslint: {
            strict: {
                src: ['<%= pkg.webrootPath %>css/*.css', '!*.min.css']
            }
        },
        qunit: {
            files: ['test/**/*.html']
        },
        jshint: {
            files: ['Gruntfile.js', '<%= pkg.webrootPath %>js/*.js'],
            options: {
                globals: {
                    jQuery: true,
                    console: true,
                    module: true,
                    document: true
                }
            }
        },
        watch: {
            files: ['<%= jshint.files %>'],
            tasks: ['jshint', 'csslint', 'qunit']
        }
    });

    grunt.loadNpmTasks('grunt-contrib-uglify');
    grunt.loadNpmTasks('grunt-contrib-jshint');
    grunt.loadNpmTasks('grunt-contrib-watch');
    grunt.loadNpmTasks('grunt-contrib-qunit');
    grunt.loadNpmTasks('grunt-contrib-concat');
    grunt.loadNpmTasks('grunt-contrib-cssmin');
    grunt.loadNpmTasks('grunt-contrib-csslint');

    grunt.registerTask('test', ['jshint', 'csslint', 'qunit']);

    //grunt.registerTask('minify', ['concat', 'uglify', 'cssmin']);
	grunt.registerTask('minify', ['concat', 'uglify']);

    // grunt.registerTask('default', ['jshint', 'csslint', 'qunit', 'concat', 'cssmin', 'uglify']);
	grunt.registerTask('default', ['jshint', 'csslint', 'qunit', 'concat', 'uglify']);
};