'use strict';
var util = require('util');
var path = require('path');
var yeoman = require('yeoman-generator');
// Extra requires
var fs = require('fs-extra');
var passthru = require('passthru');

var NewjsGenerator = module.exports = function NewjsGenerator(args, options, config) {
    // By calling `NamedBase` here, we get the argument to the subgenerator call
    // as `this.name`.
    yeoman.generators.NamedBase.apply(this, arguments);

};

util.inherits(NewjsGenerator, yeoman.generators.NamedBase);

function _camelize(str) {
    return str.replace(/(?:^\w|[A-Z]|\b\w)/g, function(letter, index) {
        return index == 0 ? letter.toLowerCase() : letter.toUpperCase();
    }).replace(/\s+/g, '');
}

function _humanize(str) {
    return str.replace(/_/g, ' ')
            .replace(/-/g, ' ')
            .replace(/(\w+)/g, function(match) {
        return match.charAt(0).toUpperCase() + match.slice(1);
    });
}

function _slugify(str) {
    return str.toLowerCase().replace(/-+/g, '').replace(/\s+/g, '-').replace(/[^a-z0-9-]/g, '');
}

NewjsGenerator.prototype.askFor = function askFor() {
    var cb = this.async();

    var prompts = [
        {
            name: 'description',
            message: 'Describe this new javascript class',
            default: ''
        }
    ];
    this.prompt(prompts, function(props) {
        this.description = props.description;
        cb();
    }.bind(this));
    
    // Check for composer.json. If exists, is a CakePHP project, then change the webrootPath
    var webrootCheck = "";
    fs.readFile('composer.json', 'utf8', function(err, data) {
        if (err) {
            webrootCheck = "common/"
        } else {
            webrootCheck = "app/webroot/"
        }
    });
    
    this.webrootPath = webrootCheck;
    
};

NewjsGenerator.prototype.copyNewJs = function copyNewJs() {
    var appPkg = JSON.parse(this.readFileAsString('package.json'));

    this.projectName = _humanize(appPkg.name);
    this.camelizedScriptName = _camelize(this.name);
    this.name = _slugify(this.name);

    this.template('_default.js', this.webrootPath + 'js/' + this.name + '.js');
    this.template('_default.test.html', 'test/' + this.name + '.js/' + this.name + '.test.html');
    this.template('_default.test.js', 'test/' + this.name + '.js/' + this.name + '.test.js');
};

NewjsGenerator.prototype.setAuthors = function setAuthors() {
    var mainDev = "";
    var appPkg = JSON.parse(this.readFileAsString('package.json'));
    for (var dev in appPkg.contributors) {
        mainDev = mainDev + "\n * @author " + appPkg.contributors[dev]["name"];
    }
    var scriptName = this.name;
    var webrootPath = this.webrootPath;
    // Write to the new JS the current authors of project
    fs.readFile(webrootPath + 'js/' + scriptName + '.js', 'utf8', function(err, data) {
        if (err)
            return console.log(err);

        var result = data.replace('{mainDevelopers}', mainDev);

        fs.writeFile(webrootPath + 'js/' + scriptName + '.js', result, 'utf8', function(err) {
            if (err)
                return console.log(err);
        });
    });
};
